=========
Changelog
=========

Version 0.8.0
===========

- The core implementation is done
	- base.py contains a working implementation
	of the spetrographic idea.
- Created some examples.
- Adding requirements

Version 0.8.1
===========

- Wrote README.md
- test upload to testpypi
- create demonstrational video

Version 0.8.5
===========

- quick fix of centering in README.md

Version 0.8.6
===========

- added gitpython as dependency

Version 0.8.7
===========

- removed dependencies from config file and moved to requirements